"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var word_wrap_1 = tslib_1.__importDefault(require("word-wrap"));
var utils_1 = require("./utils");
function leadingBlankFilter(value, rule) {
    if (rule == null) {
        return value;
    }
    if (!value) {
        return value;
    }
    var level = rule[0], applicable = rule[1];
    if (level === 0 /* Disable */) {
        return value;
    }
    if (applicable === 'always') {
        return '\n' + value.trimLeft();
    }
    return value.trimLeft();
}
exports.leadingBlankFilter = leadingBlankFilter;
function fullStopFilter(value, rule) {
    if (rule == null) {
        return value;
    }
    var level = rule[0], applicable = rule[1], ruleValue = rule[2];
    if (level === 0 /* Disable */) {
        return value;
    }
    if (applicable === 'never') {
        return value.trimRight().endsWith(ruleValue) ? value.trimRight().slice(0, -1) : value;
    }
    return value.trimRight().endsWith(ruleValue) ? value : value.trimRight() + ruleValue;
}
exports.fullStopFilter = fullStopFilter;
function wordCaseFilter(value, rule) {
    if (rule == null) {
        return value;
    }
    var level = rule[0], applicable = rule[1], ruleValue = rule[2];
    if (typeof ruleValue !== 'string') {
        return value;
    }
    if (level === 0 /* Disable */) {
        return value;
    }
    if (applicable === 'never') {
        return value;
    }
    return utils_1.wordCase(value, ruleValue);
}
exports.wordCaseFilter = wordCaseFilter;
function maxLineLengthFilter(value, rule) {
    if (rule == null) {
        return value;
    }
    var level = rule[0], applicable = rule[1], ruleValue = rule[2];
    if (level === 0 /* Disable */) {
        return value;
    }
    if (applicable === 'never') {
        return value;
    }
    return word_wrap_1.default(value, { width: ruleValue, indent: '' });
}
exports.maxLineLengthFilter = maxLineLengthFilter;
